@@ -57,7 +57,6 @@ class ChatSession(object):
         """
 
         # Parameters for connection and the internal chat event loop
-        print('inside init of new session')
         self.__host = host
         self.__port = port
         self.__chat_event_loop = chat_event_loop
@@ -564,6 +563,20 @@ class ChatSession(object):
                 del_seq=[pb.SeqRange(low=low, hi=hi) for low, hi in messages],
                 hard=hard)
         }))
+    
+    async def delete_topic(self, topic: str):
+        """
+        Delete a topic, including all subscriptions and all messages. Only
+        the owner can delete a topic. Peer-to-peer topics cannot be deleted.
+
+        """
+        await self.__send_message(pb.ClientMsg(**{
+            # 'del' is a reserved keyword in python, so we use dict expansion
+            'del': pb.ClientDel(
+                topic=topic,
+                what=pb.ClientDel.TOPIC,
+                hard=True)
+        }))
 
     async def notify_key_press(self, topic: str):
         """
@@ -628,16 +641,13 @@ class ChatSession(object):
         `async with new_session():` async context manager pattern.
         """
 
-        print('closing stream', self.__user_id)
         if self.__stream is not None:
             await self.__stream.cancel()
             self.__stream = None
         
-        print('closing channel', self.__user_id)
         if self.__channel is not None:
             self.__channel.close()
             
-        print('closing message loop', self.__user_id)
         if self.__message_loop_future is not None:
             self.__message_loop_future.cancel()
 
@@ -675,11 +685,8 @@ class ChatSession(object):
         """
 
         # Connect to the server
-        print('connecting')
         self.__channel = grpclib.client.Channel(self.__host, self.__port)
-        print('created channel')
         async with pbx.NodeStub(self.__channel).MessageLoop.open() as stream:
-            print('opened stream')
             # Say hello to the server
             await stream.send_message(pb.ClientMsg(
                 hi=pb.ClientHi(
@@ -689,9 +696,7 @@ class ChatSession(object):
                     device_id=self.__device_id,
                     lang=self.__lang,
                     platform=self.__platform)))
-            print('said hi')
             hi_resp = await stream.recv_message()  # TODO timeout
-            print('got response')
             
             # Tell producers that we are ready for business
             self.__stream = stream
