@@ -30,9 +30,7 @@ def random_secret():
 @pytest.mark.asyncio
 async def test_message_loop(loop: ChatLoop):
     async with loop.new_session() as s:
-        print('inside async with')
         s._ChatSession__ensure_message_loop_started()
-        print('ensured mesage loop started')
         assert isinstance(s._ChatSession__message_loop_future, futures.Future) 
         assert not s._ChatSession__message_loop_future.done()
         assert s._ChatSession__stream is not None
@@ -334,6 +332,22 @@ async def test_find_topics_and_users_with_same_tags(loop):
         [found_topic] = await b.find_topics(tag)
         assert found_topic.topic == topic
 
+@pytest.mark.asyncio
+async def test_delete_topic(loop):
+    b_secret = random_secret()
+    async with loop.new_session() as a, loop.new_session() as b:
+        await a.register(random_secret())
+        await b.register(b_secret)
+        
+        topic = await a.new_topic()
+        await b.subscribe(topic)
+        assert len(await b.get_subscribed_topics()) == 1
+        await a.delete_topic(topic)
+        assert len(await b.get_subscribed_topics()) == 0
+        
+        with pytest.raises(Rejected):
+            await b.subscribe(topic)
+
 @pytest.mark.asyncio
 async def test_subscribe_and_attach(loop):
     async with loop.new_session() as a:
